# eric7.EricWidgets.EricAnimatedWidget

Module implementing an animated widget.

### Global Attributes

None

### Classes

EricAnimatedWidget | Class implementing an animated widget.
EricAnimationDirection | Class defining the animation directions.

### Functions

None

## EricAnimatedWidget

Class implementing an animated widget.

### Derived from

QWidget

### Class Attributes

None

### Class Methods

None

### Methods

EricAnimatedWidget | Constructor
__animateFrame | Private slot to animate the next frame.
hide | Public slot to hide the animated widget.
resizeEvent | Protected method to handle a resize event.
startAnimation | Public slot to start the animation.
widget | Public method to get a reference to the animated widget.

### Static Methods

None

#### EricAnimatedWidget (Constructor)

EricAnimatedWidget(direction=EricAnimationDirection.Down, duration=300, parent=None)

Constructor

direction (EricAnimationDirection)
  direction of the animation
duration (int)
  duration of the animation
parent (QWidget)
  reference to the parent widget

#### EricAnimatedWidget.__animateFrame

__animateFrame(frame)

Private slot to animate the next frame.

frame (int)
  frame number

#### EricAnimatedWidget.hide

hide()

Public slot to hide the animated widget.

#### EricAnimatedWidget.resizeEvent

resizeEvent(evt)

Protected method to handle a resize event.

evt (QResizeEvent)
  reference to the event object

#### EricAnimatedWidget.startAnimation

startAnimation()

Public slot to start the animation.

#### EricAnimatedWidget.widget

widget()

Public method to get a reference to the animated widget.

Return:
  reference to the animated widget

Return Type:
  QWidget

Up

## EricAnimationDirection

Class defining the animation directions.

### Derived from

enum.Enum

### Class Attributes

Down
Up

### Class Methods

None

### Methods

None

### Static Methods

None

Up